Introduction
====================
Tensordb is a vector database software independently designed and developed by Shanghai Actionsky Technology Co., Ltd.
The product realizes the efficient organization of super large-scale vector data, designs an easy to expand index structure, and effectively supports the rapid comparison of vector data in time-varying environment.
For entity analysis and relationship inference in complex scenarios, tensordb overcomes the difficulties of unstructured data management, processing and analysis faced by diversified applications in AI field, and improves the heterogeneous integration ability of database.
Tensordb has extremely high concurrent retrieval performance, supports excellent horizontal expansion ability, and provides high availability requirements in diversified business scenarios.
Tensordb is committed to providing users with one-stop unstructured data retrieval and storage solutions.


More information:
--------------------
Refer to the TensorDB API(Python) documentation for more information